@@ -5,7 +5,7 @@ from muffin import HTTPNotFound, HTTPBadRequest, HTTPForbidden
 # Package information
 # ===================
 
-__version__ = "0.0.22"
+__version__ = "0.0.28"
 __project__ = "muffin-rest"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -27,15 +27,17 @@ class RESTBadRequest(HTTPBadRequest):
 
 class RESTForbidden(HTTPForbidden):
 
-    """ Custom excption class for stopping default application error handlers. """
+    """ Custom exception class for stopping default application error handlers. """
 
     pass
 
 from .api import *      # noqa
+from .filters import *  # noqa
 from .forms import *    # noqa
 from .handlers import * # noqa
 
 try:
-    from .peewee import PWRESTHandler # noqa
+    from .peewee import PWRESTHandler           # noqa
+    from .peewee import PWFilter, PWLikeFilter  # noqa
 except ImportError:
     pass
